robotpy-cscore
==============

These are python bindings for the cscore library, which is a high performance 
library used in the FIRST Robotics competition to serve video to/from robots.
However, the core library is suitable for use in other applications, and is
comparable to something like mjpg-streamer.

This library has only been tested with Python 3, and will not work with
Python 2.7. We do not intend to support using Python 2.7.

Documentation
=============

* `Installation <http://robotpy.readthedocs.io/en/stable/install/cscore.html>`_
* `Usage <http://robotpy.readthedocs.io/en/stable/vision/index.html>`_

Author
======

Dustin Spicuzza (dustin@virtualroadside.com)
